summaryrefslogtreecommitdiffstats
path: root/dcop/KDE-ICE
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-03 04:12:51 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-03 04:12:51 +0000
commit560378aaca1784ba19806a0414a32b20c744de39 (patch)
treece0dfd7c3febf2a1adc7603d1019a8be2083c415 /dcop/KDE-ICE
parentd4d5af1cdbd3cc65d095e0afc5b1f4260091cf5d (diff)
downloadtdelibs-560378aaca1784ba19806a0414a32b20c744de39.tar.gz
tdelibs-560378aaca1784ba19806a0414a32b20c744de39.zip
Automated conversion for enhanced compatibility with TQt for Qt4 3.4.0 TP1
NOTE: This will not compile with Qt4 (yet), however it does compile with Qt3 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdelibs@1211081 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'dcop/KDE-ICE')
-rw-r--r--dcop/KDE-ICE/ICE-def.cpp2
-rw-r--r--dcop/KDE-ICE/ICEmsg.h6
-rw-r--r--dcop/KDE-ICE/ICEutil.h2
-rw-r--r--dcop/KDE-ICE/Xtrans.c8
-rw-r--r--dcop/KDE-ICE/Xtranssock.c20
-rw-r--r--dcop/KDE-ICE/authutil.c26
-rw-r--r--dcop/KDE-ICE/iceauth.c4
-rw-r--r--dcop/KDE-ICE/listen.c4
-rw-r--r--dcop/KDE-ICE/listenwk.c4
-rw-r--r--dcop/KDE-ICE/locking.c2
-rw-r--r--dcop/KDE-ICE/ping.c2
-rw-r--r--dcop/KDE-ICE/watch.c2
12 files changed, 41 insertions, 41 deletions
diff --git a/dcop/KDE-ICE/ICE-def.cpp b/dcop/KDE-ICE/ICE-def.cpp
index df1d9ea58..0bf780f59 100644
--- a/dcop/KDE-ICE/ICE-def.cpp
+++ b/dcop/KDE-ICE/ICE-def.cpp
@@ -11,7 +11,7 @@ EXPORTS
IceCloseConnection
IceComposeNetworkIdList
IceConnectionNumber
- IceConnectionStatus
+ IceConnectiontqStatus
IceConnectionString
IceFlush
IceFreeAuthFileEntry
diff --git a/dcop/KDE-ICE/ICEmsg.h b/dcop/KDE-ICE/ICEmsg.h
index cf4d98975..db76c8252 100644
--- a/dcop/KDE-ICE/ICEmsg.h
+++ b/dcop/KDE-ICE/ICEmsg.h
@@ -39,7 +39,7 @@ Author: Ralph Mor, X Consortium
#define _IceRead _kde_IceRead
-extern Status _IceRead (
+extern tqStatus _IceRead (
#if NeedFunctionPrototypes
IceConn /* iceConn */,
unsigned long /* nbytes */,
@@ -221,7 +221,7 @@ extern void _IceErrorBadValue (
/*
- * Write pad bytes. Used to force 32 or 64 bit alignment.
+ * Write pad bytes. Used to force 32 or 64 bit tqalignment.
* A maxium of 7 pad bytes can be specified.
*/
@@ -306,7 +306,7 @@ extern void _IceErrorBadValue (
/*
- * Read pad bytes (for 32 or 64 bit alignment).
+ * Read pad bytes (for 32 or 64 bit tqalignment).
* A maxium of 7 pad bytes can be specified.
*/
diff --git a/dcop/KDE-ICE/ICEutil.h b/dcop/KDE-ICE/ICEutil.h
index dd32fe620..84ebc158d 100644
--- a/dcop/KDE-ICE/ICEutil.h
+++ b/dcop/KDE-ICE/ICEutil.h
@@ -119,7 +119,7 @@ extern void IceFreeAuthFileEntry (
#define IceWriteAuthFileEntry KDE_IceWriteAuthFileEntry
-extern Status KDE_IceWriteAuthFileEntry (
+extern tqStatus KDE_IceWriteAuthFileEntry (
#if NeedFunctionPrototypes
FILE * /* auth_file */,
IceAuthFileEntry * /* auth */
diff --git a/dcop/KDE-ICE/Xtrans.c b/dcop/KDE-ICE/Xtrans.c
index 371752919..1f072d8cd 100644
--- a/dcop/KDE-ICE/Xtrans.c
+++ b/dcop/KDE-ICE/Xtrans.c
@@ -54,7 +54,7 @@ extern char *strchr(const char *, int);
#endif
/*
- * The transport table contains a definition for every transport (protocol)
+ * The transport table tqcontains a definition for every transport (protocol)
* family. All operations that can be made on the transport go through this
* table.
*
@@ -405,7 +405,7 @@ TRANS(Open) (int type, char *address)
if ((thistrans = TRANS(SelectTransport) (protocol)) == NULL)
{
- PRMSG (1,"Open: Unable to find transport for %s\n",
+ PRMSG (1,"Open: Unable to tqfind transport for %s\n",
protocol, 0, 0);
xfree (protocol);
@@ -495,7 +495,7 @@ TRANS(Reopen) (int type, int trans_id, int fd, char *port)
if (thistrans == NULL)
{
- PRMSG (1,"Reopen: Unable to find transport id %d\n",
+ PRMSG (1,"Reopen: Unable to tqfind transport id %d\n",
trans_id, 0, 0);
return NULL;
@@ -750,7 +750,7 @@ TRANS(NoListen) (char * protocol)
if ((trans = TRANS(SelectTransport)(protocol)) == NULL)
{
- PRMSG (1,"TRANS(TransNoListen): unable to find transport: %s\n",
+ PRMSG (1,"TRANS(TransNoListen): unable to tqfind transport: %s\n",
protocol, 0, 0);
return -1;
diff --git a/dcop/KDE-ICE/Xtranssock.c b/dcop/KDE-ICE/Xtranssock.c
index 7b14ca9ab..812eb7b9d 100644
--- a/dcop/KDE-ICE/Xtranssock.c
+++ b/dcop/KDE-ICE/Xtranssock.c
@@ -176,7 +176,7 @@ static int IBMsockInit = 0;
/*
* This is the Socket implementation of the X Transport service layer
*
- * This file contains the implementation for both the UNIX and INET domains,
+ * This file tqcontains the implementation for both the UNIX and INET domains,
* and can be built for either one, or both.
*
*/
@@ -910,7 +910,7 @@ TRANS(SocketUNIXCreateListener) (XtransConnInfo ciptr, char *port)
{
struct sockaddr_un sockname;
int namelen;
- int oldUmask;
+ int oldUtqmask;
int status;
unsigned int mode;
@@ -919,7 +919,7 @@ TRANS(SocketUNIXCreateListener) (XtransConnInfo ciptr, char *port)
/* Make sure the directory is created */
- oldUmask = umask (0);
+ oldUtqmask = umask (0);
#ifdef UNIX_DIR
#ifdef HAS_STICKY_DIR_BIT
@@ -930,7 +930,7 @@ TRANS(SocketUNIXCreateListener) (XtransConnInfo ciptr, char *port)
if (trans_mkdir((char*)UNIX_DIR, mode) == -1) {
PRMSG (1, "SocketUNIXCreateListener: mkdir(%s) failed, errno = %d\n",
UNIX_DIR, errno, 0);
- (void) umask (oldUmask);
+ (void) umask (oldUtqmask);
return TRANS_CREATE_LISTENER_FAILED;
}
#endif
@@ -952,7 +952,7 @@ TRANS(SocketUNIXCreateListener) (XtransConnInfo ciptr, char *port)
#endif
unlink (sockname.sun_path);
- (void) umask (oldUmask);
+ (void) umask (oldUtqmask);
if ((status = TRANS(SocketCreateListener) (ciptr,
(struct sockaddr *) &sockname, namelen)) < 0)
@@ -1011,7 +1011,7 @@ TRANS(SocketUNIXResetListener) (XtransConnInfo ciptr)
S_IFSOCK))
#endif
{
- int oldUmask = umask (0);
+ int oldUtqmask = umask (0);
#ifdef UNIX_DIR
#ifdef HAS_STICKY_DIR_BIT
@@ -1022,7 +1022,7 @@ TRANS(SocketUNIXResetListener) (XtransConnInfo ciptr)
if (trans_mkdir((char*)UNIX_DIR, mode) == -1) {
PRMSG (1, "SocketUNIXResetListener: mkdir(%s) failed, errno = %d\n",
UNIX_DIR, errno, 0);
- (void) umask (oldUmask);
+ (void) umask (oldUtqmask);
return TRANS_RESET_FAILURE;
}
#endif
@@ -1033,7 +1033,7 @@ TRANS(SocketUNIXResetListener) (XtransConnInfo ciptr)
if ((ciptr->fd = socket (AF_UNIX, SOCK_STREAM, 0)) < 0)
{
TRANS(FreeConnInfo) (ciptr);
- (void) umask (oldUmask);
+ (void) umask (oldUtqmask);
return TRANS_RESET_FAILURE;
}
@@ -1048,11 +1048,11 @@ TRANS(SocketUNIXResetListener) (XtransConnInfo ciptr)
{
close (ciptr->fd);
TRANS(FreeConnInfo) (ciptr);
- (void) umask (oldUmask);
+ (void) umask (oldUtqmask);
return TRANS_RESET_FAILURE;
}
- umask (oldUmask);
+ umask (oldUtqmask);
status = TRANS_RESET_NEW_FD;
}
diff --git a/dcop/KDE-ICE/authutil.c b/dcop/KDE-ICE/authutil.c
index 41a2eefaa..38fc68cff 100644
--- a/dcop/KDE-ICE/authutil.c
+++ b/dcop/KDE-ICE/authutil.c
@@ -62,12 +62,12 @@ extern unsigned sleep ();
#endif
#endif
-static Status read_short (FILE *file, unsigned short *shortp);
-static Status read_string (FILE *file, char **stringp);
-static Status read_counted_string (FILE *file, unsigned short *countp, char **stringp);
-static Status write_short (FILE *file, unsigned short s);
-static Status write_string (FILE *file, char *string);
-static Status write_counted_string (FILE *file, unsigned short count, char *string);
+static tqStatus read_short (FILE *file, unsigned short *shortp);
+static tqStatus read_string (FILE *file, char **stringp);
+static tqStatus read_counted_string (FILE *file, unsigned short *countp, char **stringp);
+static tqStatus write_short (FILE *file, unsigned short s);
+static tqStatus write_string (FILE *file, char *string);
+static tqStatus write_counted_string (FILE *file, unsigned short count, char *string);
@@ -322,7 +322,7 @@ IceAuthFileEntry *auth;
-Status
+tqStatus
IceWriteAuthFileEntry (auth_file, auth)
FILE *auth_file;
@@ -398,7 +398,7 @@ const char *auth_name;
* local routines
*/
-static Status
+static tqStatus
read_short (FILE *file, unsigned short *shortp)
{
unsigned char file_short[2];
@@ -411,7 +411,7 @@ read_short (FILE *file, unsigned short *shortp)
}
-static Status
+static tqStatus
read_string (FILE *file, char **stringp)
{
unsigned short len;
@@ -447,7 +447,7 @@ read_string (FILE *file, char **stringp)
}
-static Status
+static tqStatus
read_counted_string (FILE *file, unsigned short *countp, char **stringp)
{
unsigned short len;
@@ -481,7 +481,7 @@ read_counted_string (FILE *file, unsigned short *countp, char **stringp)
}
-static Status
+static tqStatus
write_short (FILE *file, unsigned short s)
{
unsigned char file_short[2];
@@ -496,7 +496,7 @@ write_short (FILE *file, unsigned short s)
}
-static Status
+static tqStatus
write_string (FILE *file, char *string)
{
unsigned short count = strlen (string);
@@ -511,7 +511,7 @@ write_string (FILE *file, char *string)
}
-static Status
+static tqStatus
write_counted_string (FILE *file, unsigned short count, char *string)
{
if (!write_short (file, count))
diff --git a/dcop/KDE-ICE/listen.c b/dcop/KDE-ICE/listen.c
index 03b715c27..0547a6243 100644
--- a/dcop/KDE-ICE/listen.c
+++ b/dcop/KDE-ICE/listen.c
@@ -36,7 +36,7 @@ Author: Ralph Mor, X Consortium
#include <string.h>
-Status
+tqStatus
IceListenForConnections (countRet, listenObjsRet, errorLength, errorStringRet)
int *countRet;
@@ -50,7 +50,7 @@ char *errorStringRet;
int transCount, partial, i, j;
int result = -1;
int count = 0;
- Status status = 1;
+ tqStatus status = 1;
XtransConnInfo *transConns = NULL;
while ((result < 0) && (count < 5))
diff --git a/dcop/KDE-ICE/listenwk.c b/dcop/KDE-ICE/listenwk.c
index 80ff1dbae..21d47a66a 100644
--- a/dcop/KDE-ICE/listenwk.c
+++ b/dcop/KDE-ICE/listenwk.c
@@ -33,7 +33,7 @@ in this Software without prior written authorization from The Open Group.
#include <string.h>
-Status
+tqStatus
IceListenForWellKnownConnections (port, countRet, listenObjsRet, errorLength, errorStringRet)
char *port;
@@ -46,7 +46,7 @@ char *errorStringRet;
struct _IceListenObj *listenObjs;
char *networkId;
int transCount, partial, i, j;
- Status status = 1;
+ tqStatus status = 1;
XtransConnInfo *transConns = NULL;
diff --git a/dcop/KDE-ICE/locking.c b/dcop/KDE-ICE/locking.c
index 0acce8368..0454704cf 100644
--- a/dcop/KDE-ICE/locking.c
+++ b/dcop/KDE-ICE/locking.c
@@ -32,7 +32,7 @@ Author: Ralph Mor, X Consortium
*/
-Status
+tqStatus
IceInitThreads ()
{
diff --git a/dcop/KDE-ICE/ping.c b/dcop/KDE-ICE/ping.c
index 5c0c601d6..bfee548c8 100644
--- a/dcop/KDE-ICE/ping.c
+++ b/dcop/KDE-ICE/ping.c
@@ -26,7 +26,7 @@ Author: Ralph Mor, X Consortium
#include <KDE-ICE/ICElib.h>
#include "KDE-ICE/ICElibint.h"
-Status
+tqStatus
IcePing (iceConn, pingReplyProc, clientData)
IceConn iceConn;
diff --git a/dcop/KDE-ICE/watch.c b/dcop/KDE-ICE/watch.c
index 79a2b8910..18be1ddc5 100644
--- a/dcop/KDE-ICE/watch.c
+++ b/dcop/KDE-ICE/watch.c
@@ -27,7 +27,7 @@ Author: Ralph Mor, X Consortium
#include "KDE-ICE/ICElibint.h"
#include "KDE-ICE/globals.h"
-Status
+tqStatus
IceAddConnectionWatch (watchProc, clientData)
IceWatchProc watchProc;
diff --git a/dcop/KDE-ICE/iceauth.c b/dcop/KDE-ICE/iceauth.c
index 72297ceb5..f8bb87785 100644
--- a/dcop/KDE-ICE/iceauth.c
+++ b/dcop/KDE-ICE/iceauth.c
@@ -135,7 +135,7 @@ char **errorStringRet;
if (!data)
{
const char *tempstr =
- "Could not find correct MIT-MAGIC-COOKIE-1 authentication";
+ "Could not tqfind correct MIT-MAGIC-COOKIE-1 authentication";
*errorStringRet = (char *) malloc (strlen (tempstr) + 1);
if (*errorStringRet)
@@ -243,7 +243,7 @@ char **errorStringRet;
/*
* We should never get here because in the ConnectionReply
* we should have passed all the valid methods. So we should
* always find a valid entry.
*/
const char *tempstr =
@@ -243,7 +243,7 @@ char **errorStringRet;
* We should never get here because in the ConnectionReply
* we should have passed all the valid methods. So we should
- * always find a valid entry.
+ * always tqfind a valid entry.
*/
const char *tempstr =